# Changelog

## 2024-01-12 - 0.2.1 - Fix readme and docs

### Updates
- Fix readme and docs

### Todo
- manage crop video
- fix dict error
- fix list random error
- clean files
- drop useless comments
- upgrade test policy

## 2024-01-11 - 0.2.0 - 2nd release

### Updates
- rename awdible from audible
- reshape all app
- reshape Awdible class

### Added
- add true cli suport
- add tets
- add console


## 2024-01-11 - 0.1.2 - Fix Streamlit

### Updates
- Fix streamlit problem
- Update readme
- Clean the repo

### Todo
- Add better UI / UX front end, fancy and care instructions for the user
- Multi page app
- Front feature for cropping video in n parts
- Front feature for takin a keyword screen and not the video url
- Clean deps
- Add subtitles support feature
- Update test policy and add more tests

## 2024-01-10 - 0.1.1 - Light UI/UX update

### Updates
- Added a more welcoming UI/UX

## 2024-01-10 - 0.1.0 - 1st release

### Updates
- First public version
- Core features such as input video, and download video
